Mercator - Data Mapper for Protobuf
===================================

``version 0.0.1``

Python DSL to leverage translation of dictionaries and SQLAlchemy into Protobuf objects

.. image:: https://readthedocs.org/projects/mercator/badge/?version=latest
   :target: http://mercator.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status
.. image:: https://travis-ci.org/NewStore/mercator.svg?branch=master
    :target: https://travis-ci.org/NewStore/mercator
.. |PyPI python versions| image:: https://img.shields.io/pypi/pyversions/mercator.svg
   :target: https://pypi.python.org/pypi/mercator
.. |Join the chat at https://gitter.im/NewStore/mercator| image:: https://badges.gitter.im/NewStore/mercator.svg
   :target: https://gitter.im/NewStore/mercator?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge


Install
-------

.. code:: bash

   pip install mercator


Documentation
-------------

`https://mercator.readthedocs.org <https://mercator.readthedocs.org>`_


Basic Usage
-----------


.. code:: protobuf



.. code:: python



Contributing
------------

#. Check the `code structure documentation <CODE_STRUCTURE.rst>`_
#. Write tests
#. Write code
#. Send a pull-request
